Faucet Documentation
====================

User Documentation
------------------

.. toctree::
   :maxdepth: 2

   intro
   tutorials/index
   installation
   docker
   configuration
   recipe_book/index
   vendors/index
   external_resources

Developer Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   developer_guide
   architecture
   testing
   fuzzing
   source/index

Quick References
----------------

.. toctree::
   :maxdepth: 1

   faq


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
